@@ -10,9 +10,9 @@
    Tyrell DarkIce
 
    File     : AlsaDspSource.h
-   Version  : $Revision: 474 $
+   Version  : $Revision: 553 $
    Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL$
+   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/AlsaDspSource.h $
    
    Copyright notice:
 
@@ -67,7 +67,7 @@
  *  An audio input based on the ALSA sound system 
  *
  *  @author  $Author: rafael@riseup.net $
- *  @version $Revision: 474 $
+ *  @version $Revision: 553 $
  */
 class AlsaDspSource : public AudioSource, public virtual Reporter
 {
