@@ -5,9 +5,9 @@
    Tyrell DarkIce
 
    File     : IceCast2.cpp
-   Version  : $Revision: 474 $
+   Version  : $Revision: 553 $
    Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL$
+   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/IceCast2.cpp $
    
    Copyright notice:
 
@@ -67,20 +67,15 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: IceCast2.cpp 474 2010-05-10 01:18:15Z rafael@riseup.net $";
-
-
-/*------------------------------------------------------------------------------
- *  Size of string conversion buffer
- *----------------------------------------------------------------------------*/
-#define STRBUF_SIZE         32
+static const char fileid[] = "$Id: IceCast2.cpp 553 2013-07-15 05:50:56Z rafael@riseup.net $";
 
 
 /*------------------------------------------------------------------------------
  *  Expected positive response from server begins like this.
  *----------------------------------------------------------------------------*/
 static const char responseOK[] = "HTTP/1.0 200";
-
+static const char responseWrongPasswd[] = "HTTP/1.0 401";
+static const char responseForbidden[] = "HTTP/1.0 403";
 
 /* ===============================================  local function prototypes */
 
@@ -124,7 +119,8 @@ IceCast2 :: sendLogin ( void )                           throw ( Exception )
     Sink          * sink   = getSink();
     Source        * source = getSocket();
     const char    * str;
-    char            resp[STRBUF_SIZE];
+    const int       buflen = 1024;  // some small buffer size
+    char            resp[buflen];   // a little buffer
     unsigned int    len;
     unsigned int    lenExpected;
 
@@ -157,6 +153,10 @@ IceCast2 :: sendLogin ( void )                           throw ( Exception )
             str = "application/ogg";
             break;
 
+        case oggOpus:
+            str = "application/ogg";
+            break;
+
         case aac:
             str = "audio/aac";
             break;
@@ -177,7 +177,7 @@ IceCast2 :: sendLogin ( void )                           throw ( Exception )
     sink->write( str, strlen(str));
     {
         // send source:<password> encoded as base64
-        char        * source = "source:";
+        const char  * source = "source:";
         const char  * pwd    = getPassword();
         char        * tmp    = new char[Util::strLen(source) +
                                         Util::strLen(pwd) + 1];
@@ -196,10 +196,7 @@ IceCast2 :: sendLogin ( void )                           throw ( Exception )
     // send the ice- headers
     str = "\nice-bitrate: ";
     sink->write( str, strlen( str));
-    if ( log10(getBitRate()) >= (STRBUF_SIZE-2) ) {
-        throw Exception( __FILE__, __LINE__,
-                         "bitrate does not fit string buffer", getBitRate());
-    }
+    
     sprintf( resp, "%d", getBitRate());
     sink->write( resp, strlen( resp));
 
@@ -242,18 +239,34 @@ IceCast2 :: sendLogin ( void )                           throw ( Exception )
 
     // read the response, expected response begins with responseOK
     lenExpected = Util::strLen( responseOK);
-    if ( (len = source->read( resp, STRBUF_SIZE-1)) < lenExpected ) {
-        return false;
+    if ( (len = source->read( resp, buflen )) < lenExpected ) {
+        return false; // short read, no need to continue
     }
-    resp[lenExpected] = 0;
+    resp[lenExpected] = '\x00'; // end string, truncate to expected length
+
+    reportEvent(5,resp);
+
+    if ( Util::strEq( resp, responseWrongPasswd) ) {
+	throw Exception( __FILE__, __LINE__,
+                         "Icecast2 - wrong password");
+    }
+
+    if ( Util::strEq( resp, responseForbidden) ) {
+	throw Exception( __FILE__, __LINE__,
+                         "Icecast2 - forbidden. Is the mountpoint occupied, or maximum sources reached?");
+    }
+
     if ( !Util::strEq( resp, responseOK) ) {
-        return false;
+        // some unexpected response from server
+        throw Exception( __FILE__, __LINE__,
+                         "Icecast2 - Unexpected response from server");
     }
     
     // suck anything that the other side has to say
     while ( source->canRead( 0, 0) && 
-           (len = source->read( resp, STRBUF_SIZE-1)) );
-
+           (len = source->read( resp, buflen )));
+    
+    // all is well, we are connected
     return true;
 }
 
