@@ -7,9 +7,9 @@
    Tyrell DarkIce
 
    File     : JackDspSource.h
-   Version  : $Revision: 474 $
+   Version  : $Revision: 553 $
    Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL$
+   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/JackDspSource.h $
    
    Copyright notice:
 
@@ -62,7 +62,7 @@
  *  An audio input based on JACK
  *
  *  @author  $Author: rafael@riseup.net $
- *  @version $Revision: 474 $
+ *  @version $Revision: 553 $
  */
 class JackDspSource : public AudioSource, public virtual Reporter
 {
