@@ -5,9 +5,9 @@
    Tyrell DarkIce
 
    File     : MultiThreadedConnector.h
-   Version  : $Revision: 474 $
+   Version  : $Revision: 553 $
    Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL$
+   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/MultiThreadedConnector.h $
    
    Copyright notice:
 
@@ -69,7 +69,7 @@
  *  producer - consumer approach.
  *
  *  @author  $Author: rafael@riseup.net $
- *  @version $Revision: 474 $
+ *  @version $Revision: 553 $
  */
 class MultiThreadedConnector : public virtual Connector
 {
