@@ -5,9 +5,9 @@
    Tyrell DarkIce
 
    File     : OssDspSource.h
-   Version  : $Revision: 474 $
+   Version  : $Revision: 553 $
    Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL$
+   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/OssDspSource.h $
    
    Copyright notice:
 
@@ -52,7 +52,7 @@
  *  An audio input based on /dev/dsp-like raw devices
  *
  *  @author  $Author: rafael@riseup.net $
- *  @version $Revision: 474 $
+ *  @version $Revision: 553 $
  */
 class OssDspSource : public AudioSource, public virtual Reporter
 {
