@@ -5,15 +5,15 @@
    Tyrell DarkIce
 
    File     : TwoLameLibEncoder.cpp
-   Version  : $Revision: 395 $
-   Author   : $Author: darkeye $
-   Location : $HeadURL$
+   Version  : $Revision: 553 $
+   Author   : $Author: rafael@riseup.net $
+   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/TwoLameLibEncoder.cpp $
    
    Copyright notice:
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License  
-    as published by the Free Software Foundation; either version 2
+    as published by the Free Software Foundation; either version 3
     of the License, or (at your option) any later version.
    
     This program is distributed in the hope that it will be useful,
@@ -51,7 +51,7 @@
 /*------------------------------------------------------------------------------
  *  File identity
  *----------------------------------------------------------------------------*/
-static const char fileid[] = "$Id: TwoLameLibEncoder.cpp 395 2007-02-19 07:55:42Z darkeye $";
+static const char fileid[] = "$Id: TwoLameLibEncoder.cpp 553 2013-07-15 05:50:56Z rafael@riseup.net $";
 
 
 /* ===============================================  local function prototypes */
