@@ -5,9 +5,9 @@
    Tyrell DarkIce
 
    File     : Util.h
-   Version  : $Revision: 474 $
+   Version  : $Revision: 553 $
    Author   : $Author: rafael@riseup.net $
-   Location : $HeadURL$
+   Location : $HeadURL: https://darkice.googlecode.com/svn/darkice/tags/darkice-1_2/src/Util.h $
    
    Copyright notice:
 
@@ -61,7 +61,7 @@
  *  </pre>
  *
  *  @author  $Author: rafael@riseup.net $
- *  @version $Revision: 474 $
+ *  @version $Revision: 553 $
  */
 class Util
 {
@@ -187,13 +187,11 @@ class Util
          *  Convert a string to long.
          *
          *  @param str the string to convert.
-         *  @param base numeric base of number in str.
          *  @return the value of str as a long int
          *  @exception Exception
          */
         static long int
-        strToL ( const char    * str,
-                 int             base = 10 )         throw ( Exception );
+        strToL ( const char    * str) throw ( Exception );
 
         /**
          *  Convert a string to double.
